@@ -5,6 +5,7 @@ import os
 from pyramid.renderers import render
 from pyramid.threadlocal import get_current_request
 from pyramid.response import Response
+from pyramid_debugtoolbar import ipaddr
 from pyramid_debugtoolbar.tbtools import get_traceback
 from pyramid_debugtoolbar.compat import url_unquote
 from pyramid_debugtoolbar.compat import bytes_
@@ -100,8 +101,14 @@ def toolbar_tween_factory(handler, registry):
         request.exc_history = exc_history
         remote_addr = request.remote_addr
 
-        if (request.path.startswith(root_path) or (not remote_addr in hosts)):
+        if request.path.startswith(root_path):
             return handler(request)
+        else:
+            for host in hosts:
+                if ipaddr.IPAddress(remote_addr) in ipaddr.IPNetwork(host):
+                    break
+            else:
+                return handler(request)
 
         toolbar = DebugToolbar(request, panel_classes)
         request.debug_toolbar = toolbar
